@@ -1032,7 +1032,9 @@ enum fileactions action;
  
  Debug1("method = %c\n", method);
  
- new_sec_acls[0]= calloc(1, sizeof(sec_acl_p_t));
+ /* new_sec_acls[0]= calloc(1, sizeof(sec_acl_p_t));*/
+ new_sec_acls[0]= calloc(1, sizeof(sec_acl_t));
+
  new_sec_acls[0]->sec_acl_entries = calloc(MAXDFSACL, sizeof(sec_acl_entry_t));
  new_sec_acls[0]->default_realm = acl_list.sec_acls[0]->default_realm;
  new_sec_acls[0]->sec_acl_manager_type = acl_list.sec_acls[0]->sec_acl_manager_type;
