@@ -192,7 +192,7 @@ extern int errno;
 #  include <arpa/inet.h>
 # endif
 # include <netdb.h>
-# ifndef LINUX
+# if !defined LINUX && !defined NT
 # include <sys/protosw.h>
 # undef sgi
 # include <net/route.h>
@@ -240,6 +240,15 @@ char *strdup();
 #define ticksperday 86400 /* 60 * 60 *24 */
 
 
+/* Need this to to avoid conflict with solaris 2.6 and db.h */
+
+#ifdef SOLARIS
+# define u_int32_t uint32_t
+# define u_int16_t uint16_t
+# define u_int8_t uint8_t
+#endif
+
+
 /*******************************************************************/
 /* Class array limits                                              */
 /* This is the only place you ever need to edit anything           */
@@ -266,9 +275,12 @@ char *strdup();
 #define CFD_TERMINATOR "---cfengine"
 #define CFD_TRUE "CFD_TRUE"
 #define CFD_FALSE "CFD_FALSE"
+#define CF_NOUSER -99
 
 #define CFFAILEDSTR "BAD: Host authentication failed. Did you forget the domain name in cfengine.conf or cfd.conf?"
 
+#define CF_START_DOMAIN "undefined.domain"
+
 #define CFLOGSIZE 16384                  /* Size of lock-log before rotation */
 
 /* Output control defines */
@@ -465,6 +477,7 @@ enum classes
    linuxx,
    solaris,
    osf,
+   digital,
    sun3,
    irix4,
    irix,
@@ -547,6 +560,7 @@ enum fileattr
    cfdeldir,
    cfdelfstab,
    cfstealth,
+   cfchksum,
    cfbad
    };
 
@@ -981,6 +995,7 @@ struct File
    struct Item *acl_aliases;
    char   log;
    char   inform;
+   char   checksum;   /* m=md5 n=none */
    };
 
 /*******************************************************************/
@@ -1158,6 +1173,8 @@ struct ShellComm
    char              *name;
    char              *classes;
    int               timeout;
+   uid_t             uid;
+   gid_t             gid;
    char              useshell;
    struct ShellComm  *next;
    char              log;
