@@ -61,6 +61,8 @@ extern char REPOSCHAR;
 extern char DISCOMP;
 extern char USESHELL;
 extern char PURGE;
+extern char CHECKSUM;
+extern int CHECKSUMUPDATES;
 extern int  DISABLESIZE;
 
 extern char VLOGDIR[];
@@ -115,6 +117,8 @@ extern char     MOUNTFROM[bufsize];
 extern char     MOUNTONTO[bufsize];
 extern char   DESTINATION[bufsize];
 extern char   IMAGEACTION[bufsize];
+extern char CHECKSUMDB[bufsize];
+
 
 extern char *HASH[hashtablesize];
 
@@ -226,6 +230,7 @@ extern short LOGGING;
 extern short INFORM_save;
 extern short LOGGING_save;
 extern short CFPARANOID;
+extern short SHOWACTIONS;
 
 extern short TIDYDIRS;
 extern short TRAVLINKS;
