@@ -46,14 +46,6 @@
 # include <tcpd.h>
 #endif
 
-#if defined HAVE_DB_H && defined HAVE_DB_185_H
-# include <db.h>
-#endif
-
-#if HAVE_DB_DB_H
-# include <db/db.h>
-#endif
-
 #ifdef HAVE_PTHREAD_H
 # include <pthread.h>
 #endif
@@ -102,7 +94,7 @@ int argc;
 char **argv;
 
 { extern char *optarg;
-  int optindex = 0;
+ int optindex = 0;
   int c, i;
 
 umask(0);
@@ -294,9 +286,15 @@ else
    CFD_INTERVAL = 0;
    }
 
- Debug("MaxConnections = %d\n",CFD_MAXPROCESSES);
- Debug("AutoExecInterval = %d\n",CFD_INTERVAL);
+Debug("MaxConnections = %d\n",CFD_MAXPROCESSES);
+Debug("AutoExecInterval = %d\n",CFD_INTERVAL);
 
+CHECKSUMUPDATES = true;
+ 
+if (GetMacroValue("ChecksumUpdates") && (strcmp(GetMacroValue("ChecksumUpdates"),"off") == 0))
+  {
+  CHECKSUMUPDATES = false;
+  } 
  
 i = 0;
 
@@ -1134,8 +1132,8 @@ VerifyConnection(conn,buf)
 struct cfd_connection *conn;
 char buf[bufsize];
 
-{ struct sockaddr_in saddr,raddr;
-  char ipstring[maxvarsize], fqname[bufsize];
+{ struct sockaddr_in raddr;
+  char ipstring[maxvarsize], fqname[bufsize], username[bufsize];
   char name1[bufsize], name2[bufsize], name3[bufsize];
   struct hostent *hp;
   int len, i, j, found;
@@ -1144,18 +1142,19 @@ Debug("Connecting host identifies itself as %s\n",buf);
 
 bzero(ipstring,maxvarsize);
 bzero(fqname,maxvarsize);
+bzero(username,bufsize); 
 
-sscanf(buf,"%s %s",ipstring,fqname);
+sscanf(buf,"%s %s %s",ipstring,fqname,username);
 len = sizeof(struct sockaddr_in);
 
-if (getpeername(conn->sd_reply,(struct sockaddr *)&saddr,&len) == -1)
+if (getpeername(conn->sd_reply,(struct sockaddr *)&raddr,&len) == -1)
    {
-   CfLog(cferror,"Couldn't get socket address\n","getsockname");
+   CfLog(cferror,"Couldn't get socket address\n","getpeername");
    return false;
    }
 
 strcpy(name1,ToLowerStr(fqname));
-strcpy(name2,ToLowerStr(inet_ntoa(saddr.sin_addr))); 
+strcpy(name2,ToLowerStr(inet_ntoa(raddr.sin_addr))); 
 strcpy(name3,ToLowerStr(ipstring));
  
 sprintf(OUTPUT,"Socket originates from %s=%s\n",name2,name1);
@@ -1163,7 +1162,7 @@ CfLog(cfverbose,OUTPUT,"");
 
 #ifdef HAVE_TCPD_H
 
-if (!hosts_ctl("cfd",name1,name2,STRING_UNKNOWN))
+if (!hosts_ctl("cfd",name1,name2,username))
    {
    Verbose("TCPwrappers rejects this packet.");
    return false;
@@ -1194,7 +1193,7 @@ if ((hp = gethostbyname(name1)) == NULL)
  for (i = 0; hp->h_addr_list[i]; i++)
     {
     if (memcmp(hp->h_addr_list[i],
-	       (char *) &saddr.sin_addr, sizeof(saddr.sin_addr)) == 0)
+	       (char *) &raddr.sin_addr, sizeof(raddr.sin_addr)) == 0)
        {
        break;                     /* name is good, keep it */
        }
@@ -1223,11 +1222,14 @@ if ((hp = gethostbyname(name1)) == NULL)
     sprintf(OUTPUT,"Reverse hostname lookup failed, host claiming to be %s was %s\n",buf,inet_ntoa(raddr.sin_addr));
     CfLog(cfinform,OUTPUT,"");
     return false;
-    } 
- 
- Debug("Host ID verified as %s\n",name1);
+    }
+
+Debug("Host ID is %s\n",name1);
 strncpy(conn->hostname,name1,maxvarsize);
-return true;   
+
+Debug("User ID is %s\n",username); 
+strncpy(conn->username,username,maxvarsize);
+ return true;   
 }
 
 /**************************************************************/
@@ -1568,11 +1570,10 @@ CompareLocalChecksum(conn,sendbuffer,recvbuffer)
 struct cfd_connection *conn;
 char *sendbuffer, *recvbuffer;
 
-{ unsigned char digest1[17],digest2[17], num[5],filename[bufsize];
+{ unsigned char digest[17], num[5],filename[bufsize];
   char *sp;
   int i;
 
-
 sscanf(recvbuffer,"MD5 %s",filename);
 
 for (sp = recvbuffer+5; *sp != ' '; sp++)
@@ -1583,47 +1584,36 @@ for (i = 0; i < 16; i++)
    {
    bzero(num,5);
    sscanf(sp,"%s",num);
-
-   digest1[i] = (char) atoi(num);
+   digest[i] = (char) atoi(num);
    sp += strlen((char *)num) + 1;
    }
-
-digest2[16] = '\0'; /* for libdb */
-
-Debug("CompareLocalChecksums(%16s)\n",digest1);
-
+ 
+Debug("CompareLocalChecksums(%s)\n",cfMDPrint(digest));
 bzero(sendbuffer,bufsize);
 
-if (! InChecksumDB(filename,digest2))
+if (ChecksumChanged(filename,digest,cfverbose,true))
    {
-   cfMDFile(filename,digest2);
-   }
-
-for (i = 0; i < 16; i++)
-   {
-   if (digest1[i] != digest2[i])
+   sprintf(sendbuffer,"%s",CFD_TRUE);
+   Debug("Checksums didn't match\n");
+   
+   if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
       {
-      sprintf(sendbuffer,"%s",CFD_TRUE);
-      Debug("Checksums didn't match\n");
-
-      if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
-         {
-         CfLog(cferror,"","send");
-         }
-      
+      CfLog(cferror,"","send");
+      }
+   
+   return;
+   }
+else
+   {
+   sprintf(sendbuffer,"%s",CFD_FALSE);
+   Debug("Checksums matched ok\n");
+   
+   if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
+      {
+      CfLog(cferror,"","send");
       return;
       }
    }
-
-sprintf(sendbuffer,"%s",CFD_FALSE);
-
-Debug("Checksums matched ok\n");
-
-if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
-   {
-   CfLog(cferror,"","send");
-   return;
-   }
 }
 
 /**************************************************************/
@@ -1739,8 +1729,10 @@ void *CfGetFile(args)
 struct cfd_thread_arg *args;
 
 { int sd,fd, n_read;
+  uid_t uid;
   char sendbuffer[bufsize], *filename;
   struct stat statbuf;
+  struct passwd *pw;
 #ifdef HAVE_UTIME_H
   struct utimbuf timebuf;
 #endif
@@ -1769,9 +1761,43 @@ if (MULTITHREAD && (pthread_mutex_unlock(&mutex) != 0))
 sd         = (args->connect)->sd_reply;
 filename   = args->replyfile;
 
+if ((pw=getpwnam((args->connect)->username)) == NULL)
+   {
+   uid = -2;
+   }
+else
+   {
+   uid = pw->pw_uid;
+   }
+
 Debug("CfGetFile(%s on sd=%d)\n",filename,sd);
 
-stat(filename,&statbuf);             
+stat(filename,&statbuf);
+
+/* Now check to see if we have remote permission */
+
+if (statbuf.st_uid == uid)
+   {
+   Debug("Caller %s is the owner of the file\n",(args->connect)->username);
+   }
+else
+   {
+   /* We are not the owner of the file and we don't care about groups */
+   if (statbuf.st_mode & S_IROTH)
+      {
+      Debug("Caller %s not owner of the file but permission granted\n",(args->connect)->username);
+      }
+   else
+      {
+      Debug("Caller %s not owner of the file permission denied\n",(args->connect)->username);
+      RefuseAccess(args->connect->sd_reply,sendbuffer);
+      DeleteConn(args->connect);
+ 
+      free(args->replyfile);  /* from strdup in each thread */ 
+      free((char *)args);
+      return;
+      }
+   }
 
  if ((fd = open(filename,O_RDONLY)) == -1)
    {
@@ -1807,14 +1833,7 @@ else
    close(fd);
    }
 
-/* Preserve times on files. Stealthy */ 
 
-#ifdef HAVE_UTIME_H
-timebuf.actime = statbuf.st_atime;
-timebuf.modtime = statbuf.st_mtime;
-utime(filename,&timebuf);
-#endif
- 
 DeleteConn(args->connect);
  
 free(args->replyfile);  /* from strdup in each thread */ 
@@ -1856,128 +1875,6 @@ if (send(conn->sd_reply,buffer,bufsize,0) == -1)
    }
 }
 
-/***************************************************************/
-
-InChecksumDB(filename,digest)
-
-char *filename;
-char digest[17];
-
-{     
-#if defined HAVE_LIBDB && (defined HAVE_DB_H || defined HAVE_DB_DB_H) && defined HAVE_DB_185_H
-  struct stat stat1, stat2;
-  int i, uptodate = true;
-  DBT key,value;
-  DB *dbp;
-  DBC *dbcp;
-  DB_INFO dbinfo;
-  db_recno_t recno;
-	
-Debug("InChecksumDB(%s from %s)\n",filename,CHECKSUMDB);
-  
-if (stat(filename,&stat1) == -1)
-   {
-   return false;
-   }
-
-if (stat(CHECKSUMDB,&stat2) != -1)
-   {
-   if (stat1.st_mtime > stat2.st_mtime)
-      {
-      uptodate = false;
-      }
-   }
-  
-if (CHECKSUMDB[0] == '\0')
-   {
-   Verbose("cfd: No cache database defined\n");
-   return false;
-   }
- 
- /* Initialize the database. */
- memset(&dbinfo, 0, sizeof(dbinfo));
- dbinfo.db_cachesize = 32 * 1024;	/* Cachesize: 32K. */
- dbinfo.db_pagesize = 1024;		/* Page size: 1K. */
- 
- /* Create the database. */
- if ((errno = db_open(CHECKSUMDB,DB_BTREE, DB_CREATE, 0644, NULL, &dbinfo, &dbp)) != 0)
-    {
-    sprintf(OUTPUT,"cfd: couldn't open checksum database %s\n",CHECKSUMDB);
-    CfLog(cferror,OUTPUT,"db_open");
-    return false;
-    }
-
-bzero(&value,sizeof(value)); 
-bzero(&key,sizeof(key));       
-      
-key.data = filename;
-key.size = strlen(filename)+1;
- 
-if ((errno = dbp->get(dbp,NULL,&key,&value,0)) == 0)
-   {
-   if (uptodate)
-      {
-      Debug("cfd: Found checksum for %s in database\n",filename);
-      bcopy(value.data,digest,17);
-      dbp->close(dbp,0);
-      return true;
-      }
-   else
-      {
-      cfMDFile(filename,digest);
-      digest[16] = '\0';
-              
-      key.data = filename;
-      key.size = strlen(filename)+1;
-      value.data = (void *) digest;
-      value.size = 17;
-
-      Debug("cfd: updating checksum for %s\n",filename);
-      
-      if ((errno = dbp->del(dbp,NULL,&key,0)) != 0)
-	 {
-	 CfLog(cferror,"","db_store");
-	 }
-
-      key.data = filename;
-      key.size = strlen(filename)+1;
-
-      if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
-	 {
-	 CfLog(cferror,"put failed","db->put");
-	 }
-
-      dbp->close(dbp,0);
-      return true;
-      }
-   }
-else
-   {
-   CfLog(cferror,"","get");
-   cfMDFile(filename,digest);
-   digest[16] = '\0';
-
-   key.data = filename;
-   key.size = strlen(filename)+1;
-   value.data = (void *) digest;
-   value.size = 17;
-
-   Debug("cfd: storing checksum for %s in database\n",filename);
-
-   if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
-      {
-      CfLog(cferror,"put failed","db->put");
-      }
-   
-   dbp->close(dbp,0);
-   return true;   
-   }
-
-#else
-Verbose("cfd: No database support available.\n");
-return false;
-#endif
-}
 
 
 /***************************************************************/
