@@ -33,6 +33,7 @@ extern FILE *yyin;
 #define queuesize 20
 #define connection 1
 #define CFD_INPUT "cfd.conf"
+#define CFD_SOURCE 1
 
 /**********************************************************************/
 
@@ -66,6 +67,7 @@ struct cfd_connection
    int synchronized;
    int sd_reply;
    char hostname[maxvarsize];
+   char username[maxvarsize];
    };
 
 struct cfd_thread_arg
@@ -103,7 +105,6 @@ struct option CFDOPTIONS[] =
 
 char CURRENTPATH[bufsize];
 char CFRUNCOMMAND[bufsize];
-char CHECKSUMDB[bufsize];
 time_t CFDSTARTTIME;
 
 #ifdef RE_DUP_MAX
@@ -118,10 +119,3 @@ time_t CFDSTARTTIME;
 extern char *realpath(/* char *path; char resolved_path[MAXPATHLEN] */);
 #endif
 
-/* Need this to to avoid conflict with solaris 2.6 and db.h */
-
-#ifdef SOLARIS
-# define u_int32_t uint32_t
-# define u_int16_t uint16_t
-# define u_int8_t uint8_t
-#endif
