@@ -198,7 +198,7 @@ char *VMOUNTCOMM[clssattr] =
    "",
    "/etc/mount -va",      /* sun4 */
    "/etc/mount -va",      /* ultrix */
-   "/sbin/mount -va",     /* hpux10 */
+   "/sbin/mount -a",      /* hpux10 */
    "/etc/mount -va",      /* hpux */
    "/etc/mount -t nfs",   /* aix */
    "/bin/mount -va",      /* linux */
@@ -209,7 +209,7 @@ char *VMOUNTCOMM[clssattr] =
    "/sbin/mount -va",     /* irix4 */
    "/sbin/mount -va",     /* irix */
    "/sbin/mount -va",     /* irix64 */
-   "/sbin/mount -u -va",  /* freebsd */
+   "/sbin/mount -va",     /* freebsd */
    "/usr/sbin/mount -a",  /* solarisx86 */
    "/etc/mount -a",       /* bsd 4.3 */
    "/etc/mount -a",       /* newsos4 */
