@@ -129,7 +129,7 @@ signal(SIGALRM,SIG_DFL);
 
 Debug("Sending on socket...\n");
 
-if (! IdentifyForVerification(sd,VIPADDRESS,VFQNAME))
+if (! IdentifyForVerification(sd,VFQNAME))
    {
    CfLog(cferror,"Server registration procedure failed","");
    errno = EPERM;
@@ -326,7 +326,7 @@ if (err=connect(sd,(void *) &cin,sizeof(cin)) == -1)
 alarm(0);
 signal(SIGALRM,SIG_DFL);
 
-if (! IdentifyForVerification(sd,VIPADDRESS,VFQNAME))
+if (! IdentifyForVerification(sd,VFQNAME))
    {
    CfLog(cfinform,"Server registration procedure failed\n","");
    errno = EPERM;
@@ -446,7 +446,7 @@ if (err=connect(sd,(void *) &cin,sizeof(cin)) == -1)
 alarm(0);
 signal(SIGALRM,SIG_DFL);
 
-if (! IdentifyForVerification(sd,VIPADDRESS,VFQNAME))
+if (! IdentifyForVerification(sd,VFQNAME))
    {
    CfLog(cfinform,"Server registration procedure failed\n","");
    errno = EPERM;
@@ -550,7 +550,7 @@ if (err = connect(sd,(void *) &cin,sizeof(cin)) == -1)
 alarm(0);
 signal(SIGALRM,SIG_DFL);
 
-if (! IdentifyForVerification(sd,VIPADDRESS,VFQNAME))
+if (! IdentifyForVerification(sd,VFQNAME))
    {
    CfLog("Server registration procedure failed\n","");
    close(sd);
