@@ -78,6 +78,7 @@ if ((sd = open(source,O_RDONLY)) == -1)
    sprintf(OUTPUT,"Can't copy %s!\n",source);
    CfLog(cfinform,OUTPUT,"open");
    unlink(new);
+   AUTHENTICATED = false;
    return false;
    }
 
@@ -188,7 +189,7 @@ while (true)
 
     if (cf_full_write (dd, "", 1) < 0 || ftruncate (dd, n_read_total) < 0)
        {
-       CfLog(cferror,"cfengine: full_write or ftruncate error in CopyReg\n","");
+       CfLog(cferror,"cfengine: full_write or ftruncate error in CopyReg\n","write");
        free(buf);
        unlink(new);
        close(sd);
