@@ -466,7 +466,14 @@ while (ep != NULL)
                break;
 
       case InsertLine:
-                  InsertItemAfter (&filestart,CURRENTLINEPTR,ep->data);
+	          if (filestart == NULL)
+		     {
+		     AppendItem(&filestart,ep->data,NULL);
+		     }
+		  else
+		     {
+		     InsertItemAfter(&filestart,CURRENTLINEPTR,ep->data);
+		     }
                   break;
 
       case InsertFile:
@@ -1149,22 +1156,25 @@ for (ep = actions; ep != NULL; ep=ep->next)
 
    switch(ep->code)
       {
-      case AutoCreate: if (stat(filename,&statbuf) == -1)
+      case AutoCreate: if (!DONTDO)
 	                  {
-			  if ((fd = creat(filename,0644)) == -1)
+			  if (stat(filename,&statbuf) == -1)
 			     {
-			     sprintf(OUTPUT,"Unable to create file %s\n",filename);
-			     CfLog(cfinform,OUTPUT,"creat");
+			     if ((fd = creat(filename,0644)) == -1)
+				{
+				sprintf(OUTPUT,"Unable to create file %s\n",filename);
+				CfLog(cfinform,OUTPUT,"creat");
+				}
+			     else
+				{
+				AUTOCREATED = true;
+				close(fd);
+				}
+			     sprintf(OUTPUT,"Creating file %s, mode 644\n",filename);
+			     CfLog(cfinform,OUTPUT,"");
+			     return;
 			     }
-			  else
-			     {
-			     AUTOCREATED = true;
-			     close(fd);
-			     }
-			  sprintf(OUTPUT,"Creating file %s, mode 644\n",filename);
-			  CfLog(cfinform,OUTPUT,"");
-			  return;
-	                  }
+			  }
                        break;
       
       case EditBackup: if (strcmp("false",ToLowerStr(ep->data)) == 0 || strcmp("off",ToLowerStr(ep->data)) == 0)
