@@ -170,9 +170,9 @@ sscanf(buf,"%d",&i);
 
 switch ((i / 5))
    {
-   case 0: AddClassToHeap("Min0_5");
+   case 0: AddClassToHeap("Min00_05");
            break;
-   case 1: AddClassToHeap("Min5_10");
+   case 1: AddClassToHeap("Min05_10");
            break;
    case 2: AddClassToHeap("Min10_15");
            break;
@@ -468,7 +468,7 @@ for (sp = class; *sp != '\0'; sp++)
       }
 
    bzero(cbuff,maxvarsize);
-   
+
    sp += GetORAtom(sp,cbuff);
 
    if (strlen(cbuff) == 0)
@@ -493,7 +493,6 @@ for (sp = class; *sp != '\0'; sp++)
       }
    }
 
-
 return result;
 }
 
@@ -526,8 +525,8 @@ while(*sp != '\0')
       }
 
    bzero(cbuff,maxvarsize);
-   
-   sp += GetANDAtom(sp,cbuff);
+
+   sp += GetANDAtom(sp,cbuff) + 1;
 
    atom = cbuff;
 
@@ -564,7 +563,7 @@ while(*sp != '\0')
 
       continue;
       }
-
+   
    /* End of parenthesis check */
    
    if (*sp == '.')
@@ -574,21 +573,26 @@ while(*sp != '\0')
 
    if (IsItemIn(VNEGHEAP,atom))
       {
-      return false;
+      if (negation)
+         {
+	 count--;
+	 }
+      else
+	 {
+	 return false;
+	 }
       } 
-
-   if (IsItemIn(VHEAP,atom))
+   else if (IsItemIn(VHEAP,atom))
       {
       if (negation)
          {
-         return false;
+	 return false;
          }
       else
          {
          count--;
          }
       } 
- 
    else if (IsItemIn(list,atom))
       {
       if (negation)
@@ -600,11 +604,14 @@ while(*sp != '\0')
          count--;
          }
       } 
-
    else if (negation)    /* ! (an undefined class) == true */
       {
       count--;
       }
+   else
+      {
+      return false;
+      }
    }
 
 if (count == 0)
@@ -673,6 +680,7 @@ while ((*sp != '\0') && !((*sp == '.') && (bracklevel == 0)))
       }
 
    *spc++ = *sp++;
+
    len++;
    }
 
