@@ -239,6 +239,7 @@ struct Item *acl_aliases;
 
 { mode_t newperm = dstat->st_mode;
   int amroot = true;
+  char digest[17];
 
 Verbose("%s: Checking fs-object %s\n",VPREFIX,file);
 Debug("CheckExistingFile(+%o,-%o)\n",plus,minus); 
@@ -302,10 +303,10 @@ if (dstat->st_uid == 0 && (dstat->st_mode & S_ISUID))
       if (! IsItemIn(VSETUIDLIST,file))
          {
          if (amroot)
-	     {
-	     sprintf(OUTPUT,"NEW SETUID root PROGRAM %s\n",file);
-	     CfLog(cfinform,OUTPUT,"");
-	     }
+	    {
+	    sprintf(OUTPUT,"NEW SETUID root PROGRAM %s\n",file);
+	    CfLog(cfinform,OUTPUT,"");
+	    }
          PrependItem(&VSETUIDLIST,file,NULL);
          }
       }
@@ -350,10 +351,10 @@ if (dstat->st_uid == 0 && (dstat->st_mode & S_ISGID))
          else
             {
             if (amroot)
-		{
-		sprintf(OUTPUT,"NEW SETGID root PROGRAM %s\n",file);
-		CfLog(cferror,OUTPUT,"");
-		}
+	       {
+	       sprintf(OUTPUT,"NEW SETGID root PROGRAM %s\n",file);
+	       CfLog(cferror,OUTPUT,"");
+	       }
             PrependItem(&VSETUIDLIST,file,NULL);
             }
          }
@@ -390,6 +391,17 @@ if (CheckOwner(file,action,uidlist,gidlist,dstat))
       }
    }
 
+if ((ptr != NULL) && S_ISREG(dstat->st_mode) && (ptr->checksum == 'm'))
+    {
+    Verbose("Checking MD5 integrity of %s\n",file);
+    cfMDFile(file,digest);
+    digest[16] = '\0';
+    
+    if (ChecksumChanged(file,digest,cfsilent,false))
+       {
+       }
+    }
+ 
 if (S_ISLNK(dstat->st_mode))             /* No point in checking permission on a link */
    {
    KillOldLink(file);
@@ -664,13 +676,13 @@ else
                         {
                         if (uid != -1)
                            {
-                           sprintf(OUTPUT,"  (Changing owner to uid %d)\n",uid);
+                           sprintf(OUTPUT,"  (Change owner to uid %d if possible)\n",uid);
                            CfLog(cfinform,OUTPUT,"");
                            }
 
                         if (gid != -1)
                            {
-                           sprintf(OUTPUT,"  (Changing group to gid %d)\n",gid);
+                           sprintf(OUTPUT,"  (Change group to gid %d if possible)\n",gid);
                            CfLog(cfinform,OUTPUT,"");
                            }
                         }
@@ -683,7 +695,7 @@ else
                      if (lchown(file,uid,gid) == -1)
                         {
                         sprintf(OUTPUT,"Cannot set ownership on link %s!\n",file);
-                        CfLog(cferror,OUTPUT,"lchown");
+                        CfLog(cflogonly,OUTPUT,"lchown");
                         }
 		     else
 			{
@@ -696,7 +708,7 @@ else
                      if (chown(file,uid,gid) == -1)
                         {
                         sprintf(OUTPUT,"Cannot set ownership on file %s!\n",file);
-                        CfLog(cferror,OUTPUT,"chown");
+                        CfLog(cflogonly,OUTPUT,"chown");
                         }
 		     else
 			{
