@@ -50,6 +50,8 @@
 char VBUFF[bufsize]; /* General workspace, contents not guaranteed */
 char OUTPUT[bufsize*2];
 int AUTHENTICATED = false;
+char CHECKSUMDB[bufsize];
+int CHECKSUMUPDATES = false;
 
 /*******************************************************************/
 /*                                                                 */
@@ -105,6 +107,7 @@ int AUTHENTICATED = false;
   PUBLIC short INFORM_save;
   PUBLIC short LOGGING_save;
   PUBLIC short CFPARANOID = false;
+  PUBLIC short SHOWACTIONS = false;
 
   PRIVATE   int RPCTIMEOUT = 30;          /* seconds */
   PROTECTED int SENSIBLEFILECOUNT = 2;
@@ -477,6 +480,7 @@ int AUTHENTICATED = false;
   PRIVATE char DELETEFSTAB = 't';
   PRIVATE char FORCE = 'f';
   PRIVATE char STEALTH = 'f';
+  PRIVATE char CHECKSUM = 'n';
 
   PRIVATE char VUIDNAME[maxvarsize];
   PRIVATE char VGIDNAME[maxvarsize];
@@ -566,6 +570,7 @@ int AUTHENTICATED = false;
      "deletedir",
      "deletefstab",
      "stealth",
+     "checksum",
      NULL
      };
 
