@@ -67,6 +67,7 @@ if (strncmp(value,"exec ",5) == 0)
       {
       strncpy(command,sp,maxvarsize);
       GetExecOutput(command,value);
+      value[maxvarsize-1] = '\0';  /* Truncate to maxvarsize */
       }
    else
       {
@@ -98,7 +99,7 @@ switch (ScanVariable(CURRENTITEM))
 		      break;
 		      }
 
-                   if (strcmp(VDOMAIN,"undefined.domain") != 0)
+                   if (strcmp(VDOMAIN,CF_START_DOMAIN) != 0)
                       {
                       yyerror("Multiple declaration of variable domain");
                       FatalError("Redefinition of basic system variable");
@@ -435,6 +436,9 @@ switch(GetCommAttribute(item))
                    break;
    case cfsetinform: HandleSetInform(value);
                    break;
+
+   case cfchksum:  HandleChecksum(value);
+                   break;
    default:        yyerror("Illegal file attribute");
    }
 }
@@ -971,14 +975,18 @@ Debug1("HandleOptionalLinkAttribute(%s)\n",value);
 
 switch(GetCommAttribute(item))
    {
-   case cftimeout:  HandleTimeOut(value);
-                    break;
-   case cfuseshell: HandleUseShell(value);
-                    break;
-   case cfsetlog:  HandleSetLog(value);
-                   break;
+   case cftimeout:   HandleTimeOut(value);
+                     break;
+   case cfuseshell:  HandleUseShell(value);
+                     break;
+   case cfsetlog:    HandleSetLog(value);
+                     break;
    case cfsetinform: HandleSetInform(value);
-                   break;
+                     break;
+   case cfowner:     strcpy(VUIDNAME,value);
+		     break;
+   case cfgroup:     strcpy(VGIDNAME,value);
+                     break;
 
    default:         yyerror("Illegal shellcommand attribute");
    }
@@ -1191,7 +1199,7 @@ switch (type)
 
                    break;
 
-   case deletion:  if (strcmp(item,VDEFAULTBINSERVER.name) == 0)
+   case deletion:  if (IsDefinedClass(item))
                       {
                       DeleteItemStarting(&VHEAP,GROUPBUFF);
                       }
@@ -1750,8 +1758,8 @@ else
 switch (action)
    {
    case files:
-                  InstallFileListItem(CURRENTPATH,PLUSMASK,MINUSMASK,FILEACTION,
-				      VUIDNAME,VGIDNAME,VRECURSE,(char)PTRAVLINKS,ALLCLASSBUFFER);
+                  InstallFileListItem(CURRENTPATH,PLUSMASK,MINUSMASK,FILEACTION,VUIDNAME,
+				      VGIDNAME,VRECURSE,(char)PTRAVLINKS,ALLCLASSBUFFER,CHECKSUM);
                   break;
 
    case processes: InstallProcessItem(EXPR,RESTART,PROMATCHES,PROCOMP,
@@ -1780,7 +1788,7 @@ switch (action)
                   break;
 
    case shellcommands:
-                  AppendScript(CURRENTPATH,VTIMEOUT,USESHELL);
+                  AppendScript(CURRENTPATH,VTIMEOUT,USESHELL,VUIDNAME,VGIDNAME);
 		  break;
 
    case interfaces:
@@ -1873,6 +1881,8 @@ return false;
 
 GetExecOutput(command,buffer)
 
+/* Buffer initially contains whole exec string */
+
 char *command, *buffer;
 
 { int offset = 0;
@@ -1893,6 +1903,8 @@ if ((pp = cfpopen(command,"r")) == NULL)
    return false;
    }
 
+bzero(buffer,bufsize);
+  
 while (!feof(pp))
    {
    if (ferror(pp))  /* abortable */
@@ -1929,9 +1941,11 @@ while (!feof(pp))
    }
 
 if (offset > 0)
-    {
-    Chop(buffer); 
-    }
+   {
+   Chop(buffer); 
+   }
+
+Debug("GetExecOutput got: [%s]\n",buffer);
  
 cfpclose(pp);
 return true; 
@@ -2239,15 +2253,19 @@ InitializeAction();
 
 /*******************************************************************/
 
-AppendScript(item,timeout,useshell)
+AppendScript(item,timeout,useshell,uidname,gidname)
 
-char *item, useshell;
+char *item, useshell,*uidname,*gidname;
 int timeout;
 
 { struct TwoDimList *tp = NULL;
   struct ShellComm *ptr;
+  struct passwd *pw;
+  struct group *gw;
   char *sp;
-
+  uid_t uid = CF_NOUSER; 
+  gid_t gid = CF_NOUSER;
+  
 Debug1("Installing item (%s) in the script list\n",item);
 
 if ( ! IsInstallable(CLASSBUFF))
@@ -2294,6 +2312,61 @@ for (sp = Get2DListEnt(tp); sp != NULL; sp = Get2DListEnt(tp))
       VSCRIPTTOP->next = ptr;
       }
 
+
+   if (*uidname == '*')
+      {
+      ptr->uid = -1;      
+      }
+   else if (isdigit(*uidname))
+      {
+      sscanf(uidname,"%d",&uid);
+      if (uid == CF_NOUSER)
+	 {
+	 yyerror("Unknown or silly user id");
+	 return;
+	 }
+      else
+	 {
+	 ptr->uid = uid;
+	 }
+      }
+   else if ((pw = getpwnam(uidname)) == NULL)
+      {
+      yyerror("Unknown or silly user id");
+      return;
+      }
+   else
+      {
+      ptr->uid = pw->pw_uid;
+      }
+
+   if (*gidname == '*')
+      {
+      ptr->gid = -1;
+      }
+   else if (isdigit(*gidname))
+      {
+      sscanf(gidname,"%d",&gid);
+      if (gid == CF_NOUSER)
+	 {
+	 yyerror("Unknown or silly group id");
+	 continue;
+	 }
+      else
+	 {
+	 ptr->gid = gid;
+	 }
+      }
+   else if ((gw = getgrnam(gidname)) == NULL)
+      {
+      yyerror("Unknown or silly group id");
+      continue;
+      }
+   else
+      {
+      ptr->gid = gw->gr_gid;
+      }
+ 
    ptr->log = LOGP;
    ptr->inform = INFORMP;
    ptr->timeout = timeout;
@@ -2412,8 +2485,8 @@ for (sp = Get2DListEnt(tp); sp != NULL; sp = Get2DListEnt(tp))
 InstallTidyItem (path,wild,rec,age,travlinks,tidysize,type,ldirs,tidydirs,classes,defines)
 
 char *wild, *path;
-short age,tidysize,tidydirs;
-int rec;
+short age,tidydirs;
+int rec,tidysize;
 char type, ldirs, *classes, *defines, travlinks;
 
 { struct TwoDimList *tp = NULL;
@@ -2594,6 +2667,7 @@ else
       default:  TIDYSIZE = num * 1024;
       }
    }
+
 }
 
 /*******************************************************************/
@@ -2963,6 +3037,22 @@ yyerror("Illegal attribute for inform= ");
 
 /*******************************************************************/
 
+HandleChecksum(value)
+
+char *value;
+
+{
+if (strcmp(value,"md5") == 0)
+   {
+   CHECKSUM = 'm';
+   return;
+   }
+
+yyerror("Illegal attribute for checksum= ");
+}
+
+/*******************************************************************/
+
 HandleStealth(value)
 
 char *value;
@@ -3007,7 +3097,7 @@ return (int) warnall;
 
 /*******************************************************************/
 
-InstallFileListItem(path,plus,minus,action,uidnames,gidnames,recurse,travlinks,defines)
+InstallFileListItem(path,plus,minus,action,uidnames,gidnames,recurse,travlinks,defines,chksum)
 
 char *path, *defines;
 mode_t plus,minus;
@@ -3015,7 +3105,7 @@ enum fileactions action;
 char *uidnames;
 char *gidnames;
 int recurse;
-char travlinks;
+char travlinks,chksum;
 
 { struct File *ptr;
   char *spl;
@@ -3084,6 +3174,7 @@ for (spl = Get2DListEnt(tp); spl != NULL; spl = Get2DListEnt(tp))
    ptr->next = NULL;
    ptr->log = LOGP;
    ptr->inform = INFORMP;
+   ptr->checksum = chksum;
 
    VFILETOP = ptr;
    Debug1("Installed file object %s\n",spl);
@@ -3967,13 +4058,8 @@ for (sp = buffer; *sp != '\0'; sp+=strlen(uidbuff))
             {
             if ((pw = getpwnam(ip->name)) == NULL)
                {
-               if (VERBOSE || DEBUG || D1)
-                  {
-                  sprintf(CURRENTITEM,"Unknown user [%s]\n",ip->name);
-                  Warning(CURRENTITEM);
-                  sprintf(CURRENTITEM,"User in netgroup [%s] not in passwd file\n",uidbuff+offset);
-                  Warning(CURRENTITEM);
-                  }
+	       sprintf(OUTPUT,"Unknown user [%s]\n",ip->name);
+	       CfLog(cfverbose,OUTPUT,"getpwnam");
                continue;
                }
             else
@@ -4158,14 +4244,14 @@ InitializeAction();
 AddTidyItem(path,wild,rec,age,travlinks,tidysize,type,ldirs,tidydirs,classes,defines)
 
 char *wild, *path, *defines;
-short age,tidysize,tidydirs;
-int rec;
+short age,tidydirs;
+int rec,tidysize;
 char type, ldirs,*classes, travlinks;
 
 { char varbuff[bufsize];
   struct Tidy *ptr;
 
-Debug1("AddTidyItem(%s,pat=%s)\n",path,wild);
+Debug1("AddTidyItem(%s,pat=%s,size=%d)\n",path,wild,tidysize);
 
 if ( ! IsInstallable(CLASSBUFF))
    {
@@ -4401,8 +4487,8 @@ PrependTidy(list,wild,rec,age,travlinks,tidysize,type,ldirs,tidydirs,classes,def
 
 struct TidyPattern **list;
 char *wild;
-short age,tidysize,tidydirs;
-int rec;
+short age,tidydirs;
+int rec,tidysize;
 char type, ldirs, *classes, *defines, travlinks;
 
 { struct TidyPattern *tp;
