@@ -47,7 +47,7 @@ char *file;
 if (stat(file,&statbuf) == -1)
    {
    sprintf(OUTPUT,"Couldn't stat %s\n",file);
-   CfLog(cferror,OUTPUT,"stat");
+   CfLog(cfverbose,OUTPUT,"stat");
    return false;
    }
 
