@@ -281,7 +281,7 @@ if (maxrecurse == 0)  /* reached depth limit */
    return false;
    }
 
-if (IgnoreFile(to,""))
+if (IgnoreFile(to,"",lp->ignores))
    {
    Verbose("%s: Ignoring directory %s\n",VPREFIX,from);
    return false;
@@ -315,7 +315,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
       continue;
       }
 
-   if (IgnoreFile(to,dirp->d_name))
+   if (IgnoreFile(to,dirp->d_name,lp->ignores))
       {
       continue;
       }
@@ -814,7 +814,7 @@ if (stat(VBUFF,&statbuf) == -1)               /* link points nowhere */
    if (KILLOLDLINKS)
       {
       sprintf(OUTPUT,"Removing dead link %s\n",name);
-      CfLog(cfsilent,OUTPUT,"");
+      CfLog(cfinform,OUTPUT,"");
 
       if (! DONTDO)
          {
@@ -1108,8 +1108,7 @@ return true;
 
 /*********************************************************************/
 
-char *
-AbsLinkPath (from,relto)
+char *AbsLinkPath (from,relto)
 
 char *from, *relto;
 
@@ -1125,7 +1124,7 @@ if (*relto == '/')
    FatalError("");
    }
 
-strcpy(CURRENTPATH,from);  /* reuse to save stack space */
+strcpy(DESTINATION,from);  /* reuse to save stack space */
  
 for (sp = relto; *sp != '\0'; sp++)
    {
@@ -1147,20 +1146,20 @@ for (sp = relto; *sp != '\0'; sp++)
 
 while (pop > 0)
     {
-    ChopLastNode(CURRENTPATH);
+    ChopLastNode(DESTINATION);
     pop--;
     }
 
-if (strlen(CURRENTPATH) == 0)
+if (strlen(DESTINATION) == 0)
    {
-   strcpy(CURRENTPATH,"/");
+   strcpy(DESTINATION,"/");
    }
 else
    {
-   AddSlash(CURRENTPATH);
+   AddSlash(DESTINATION);
    }
  
-strcat(CURRENTPATH,sp);
-Debug("Reconstructed absolute linkname = %s\n",CURRENTPATH);
-return CURRENTPATH; 
+strcat(DESTINATION,sp);
+Debug("Reconstructed absolute linkname = %s\n",DESTINATION);
+return DESTINATION; 
 }
