@@ -38,6 +38,14 @@
 #include "../pub/md5.h"
 
 
+#if defined HAVE_DB_H && defined HAVE_DB_185_H
+# include <db.h>
+#endif
+
+#if HAVE_DB_DB_H
+# include <db/db.h>
+#endif
+
 /*******************************************************************/
 
 GetNameInfo()
@@ -308,6 +316,178 @@ if (statbuf.st_mode & (S_IWGRP | S_IWOTH))
 
 return true; 
 }
+/***************************************************************/
+
+ChecksumChanged(filename,digest,warnlevel,refresh)
+
+    /* Returns false if filename never seen before, and adds a checksum
+       to the database. Returns true if checksums do not match and also
+       updates database to the new value */
+    
+char *filename;
+char digest[17];
+int warnlevel,refresh;
+
+{     
+#if defined HAVE_LIBDB && (defined HAVE_DB_H || defined HAVE_DB_DB_H) && defined HAVE_DB_185_H
+  struct stat stat1, stat2;
+  int i, matched, needupdate = false;
+  DBT key,value;
+  DB *dbp;
+  DBC *dbcp;
+  db_recno_t recno;
+  char dbvalue[17],dbdigest[17];
+	
+Debug("ChecksumChanged: key %s in db %s with data %s\n",filename,CHECKSUMDB,cfMDPrint(digest));
+  
+if (CHECKSUMDB[0] == '\0')
+   {
+   CfLog(cferror,"(cfd) No database defined","");
+   return false;
+   }
+
+if (refresh)
+   {
+   /* Check whether database is current */
+
+   if (stat(filename,&stat1) == -1)
+      {
+      return false;
+      }
+   
+   if (stat(CHECKSUMDB,&stat2) != -1)
+      {
+      if (stat1.st_mtime > stat2.st_mtime)
+	 {
+	 Debug("Checksum database is older than %s...refresh needed\n",filename);
+	 needupdate = true;
+	 }
+      }
+   }
+ 
+ /* Open the database. */
+
+if ((errno = db_open(CHECKSUMDB,DB_BTREE, DB_CREATE, 0664, NULL, NULL, &dbp)) != 0)
+   {
+   sprintf(OUTPUT,"cfd: couldn't open checksum database %s\n",CHECKSUMDB);
+   CfLog(cferror,OUTPUT,"db_open");
+   return false;
+   }
+ 
+bzero(&value,sizeof(value)); 
+bzero(&key,sizeof(key));       
+      
+key.data = filename;
+key.size = strlen(filename)+1;
+value.data = dbvalue;
+value.size = 17; 
+
+if (needupdate)
+   {
+   cfMDFile(filename,digest);
+   digest[16] = '\0';
+   
+   key.data = filename;
+   key.size = strlen(filename)+1;
+   value.data = (void *) digest;
+   value.size = 17;
+   
+   Debug("cfd: updating checksum for %s to %s\n",filename,cfMDPrint(value.data));
+   
+   if ((errno = dbp->del(dbp,NULL,&key,0)) != 0)
+      {
+      CfLog(cferror,"","db_store");
+      }
+  
+   key.data = filename;
+   key.size = strlen(filename)+1;
+   
+   if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
+      {
+      CfLog(cferror,"put failed","db->put");
+      }      
+   }
+
+if ((errno = dbp->get(dbp,NULL,&key,&value,0)) == 0)
+   {
+   /* The filename key was found in the db */
+   Debug("Comparing %16s (sent) with %s (db) ",digest,cfMDPrint(value.data));
+   bcopy(value.data,dbdigest,17);
+   
+   for (i = 0; i < 16; i++)
+      {
+      if (digest[i] != dbdigest[i])
+	 {
+	 Debug("cfd: Found checksum for %s in database but it didn't match\n",filename);
+
+	 CfLog(warnlevel,"!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!","");
+	 sprintf(OUTPUT,"SECURITY ALERT: Checksum for %s changed!",filename);
+	 CfLog(warnlevel,OUTPUT,"");
+	 CfLog(warnlevel,"!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!","");
+
+	 if (CHECKSUMUPDATES)
+	    {
+	    cfMDFile(filename,digest);
+	    digest[16] = '\0';
+	    
+	    key.data = filename;
+	    key.size = strlen(filename)+1;
+	    value.data = (void *) digest;
+	    value.size = 17;
+	    
+	    Debug("cfd: updating checksum for %s to %s\n",filename,cfMDPrint(value.data));
+	    
+	    if ((errno = dbp->del(dbp,NULL,&key,0)) != 0)
+	       {
+	       CfLog(cferror,"","db_store");
+	       }
+	    
+	    key.data = filename;
+	    key.size = strlen(filename)+1;
+	    
+	    if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
+	       {
+	       CfLog(cferror,"put failed","db->put");
+	       }
+	    }
+
+	 dbp->close(dbp,0);
+	 return true;                        /* Checksum updated but was changed */
+	 }
+      }
+   
+   Debug("cfd: Found checksum for %s in database and it matched\n",filename);
+   dbp->close(dbp,0);
+   return false;
+   }
+else
+   {
+   /* Key was not found, so install it */
+   
+   cfMDFile(filename,digest);
+   digest[16] = '\0';
+
+   key.data = filename;
+   key.size = strlen(filename)+1;
+   value.data = (void *) digest;
+   value.size = 17;
+
+   Debug("cfd: storing checksum for %s in database %s\n",filename,cfMDPrint(digest));
+
+   if ((errno = dbp->put(dbp,NULL,&key,&value,0)) != 0)
+      {
+      CfLog(cferror,"put failed","db->put");
+      }
+   
+   dbp->close(dbp,0);
+   return false;      /* No need to warn when first installed */
+   }
+
+#else
+Verbose("cfd: No Berkeley DB2 database support available.\n");
+return false;
+#endif
+}
 
 /*************************************************************************/
 
@@ -392,15 +572,15 @@ char *sp;
   char *ptr;
   char buffer[bufsize];
 
-if (gethostname(fqn, sizeof(fqn)) != -1 )
+if (gethostname(fqn, sizeof(fqn)) != -1)
    {
-   if (strcmp(fqn, sp) != 0)
+   strcpy(VFQNAME,fqn);
+   strcpy(buffer,VFQNAME);
+   AddClassToHeap(CanonifyName(buffer));
+   AddClassToHeap(CanonifyName(ToLowerStr(buffer)));
+
+   if (strstr(fqn,"."))
       {
-      strcpy(VFQNAME,fqn);
-      strcpy(buffer,VFQNAME);
-      AddClassToHeap(CanonifyName(buffer));
-      AddClassToHeap(CanonifyName(ToLowerStr(buffer)));
-      
       ptr = strchr(fqn, '.');
       strcpy(VDOMAIN, ++ptr);
       }
