@@ -51,7 +51,7 @@ char *command, *type;
    int i, argc, pd[2];
    char **argv;
    pid_t pid;
-   FILE *pp;
+   FILE *pp = NULL;
 
  Debug("cfpopen(%s)\n",command);
 
@@ -85,6 +85,8 @@ char *command, *type;
        {
        case 'r':
 
+	   close(pd[0]);        /* Don't need output from parent */
+
 	   if (pd[1] != 1)
 	      {
 	      dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
@@ -92,17 +94,17 @@ char *command, *type;
 	      close(pd[1]);
 	      }
 
-	   close(pd[0]);        /* Don't need output from parent */
 	   break;
 
        case 'w':
 
+	   close(pd[1]);
+
 	   if (pd[0] != 0)
 	      {
 	      dup2(pd[0],0);
 	      close(pd[0]);
 	      }
-	   close(pd[1]);
        }
 
     for (i = 0; i < MAXFD; i++)
@@ -131,7 +133,6 @@ char *command, *type;
 	  {
 	  sprintf(OUTPUT,"Couldn't run %s",arg[0]);
 	  CfLog(cferror,OUTPUT,"execv");
-	  exit(1);
 	  }
 
        _exit(1);
