@@ -143,9 +143,21 @@ for (ip = procdata; ip != NULL; ip=ip->next)
       
       for (sp = ip->name; *sp != '\0'; sp++) /* if first field contains alpha, skip */
 	 {
-	 while (!isdigit(*sp) && (*sp != '\0'))
+	 while (true)
 	    {
-	    sp++;
+	    while (!isdigit(*sp) && (*sp != '\0'))
+	       {
+	       sp++;
+	       }
+
+	    if ((sp > ip->name) && isalnum(*(sp-1))) /* Username contains number*/
+	       {
+	       sp++;
+	       }
+	    else
+	       {
+	       break;
+	       }
 	    }
       
 	 sscanf(sp,"%d",&pid);
@@ -173,8 +185,9 @@ for (ip = procdata; ip != NULL; ip=ip->next)
 	 }
       else if (pid < 4)
 	 {
-	 printf("%s: will not signal or restart processes 0,1,2,3\n",VPREFIX);
-	 printf("%s: occurred while looking for %s\n",VPREFIX,pp->expr);
+	 Verbose("%s: will not signal or restart processes 0,1,2,3\n",VPREFIX);
+	 Verbose("%s: occurred while looking for %s\n",VPREFIX,pp->expr);
+	 continue;
 	 }
 
       if (pp->action == 'w')
@@ -194,7 +207,7 @@ for (ip = procdata; ip != NULL; ip=ip->next)
 	    if ((ret = kill((pid_t)pid,pp->signal)) < 0)
 	       {
 	       sprintf(OUTPUT,"Couldn't send signal to pid %d\n",pid);
-	       CfLog(cferror,OUTPUT,"kill");
+	       CfLog(cfverbose,OUTPUT,"kill");
 
 	       continue;
 	       }
@@ -217,7 +230,10 @@ for (ip = procdata; ip != NULL; ip=ip->next)
 
 if (pp->matches >= 0)
    {
-   AddMultipleClasses(pp->defines);
+   if (matches >= 0)
+      {
+      AddMultipleClasses(pp->defines);
+      }
 
    switch (pp->comp)
       {
