@@ -112,7 +112,7 @@ CheckForHoles(&sstat,&dummy);
 if (CopyReg(file,buffer,sstat,dstat,&dummy))
    {
    IMAGEBACKUP = imagecopy;
-   Verbose("cfengine: backed up to repository %s\n",buffer);
+   Verbose("%s: Backed up to repository %s\n",VPREFIX,buffer);
    return true;
    }
 else
