@@ -58,7 +58,7 @@ for (i = number-1; i > 0; i--)
    {
    if (BufferOverflow(name,"1"))
       {
-      printf("%s: culprit: RotateFiles in Disable:\n",VPREFIX);
+      CfLog(cferror,"Culprit: RotateFiles in Disable:\n","");
       return;
       }
    
@@ -67,7 +67,7 @@ for (i = number-1; i > 0; i--)
    
    if (rename(CURRENTITEM,VBUFF) == -1)
       {
-      Debug("cfengine: rename failed in RotateFiles %s -> %s\n",name,CURRENTITEM);
+      Debug("Rename failed in RotateFiles %s -> %s\n",name,CURRENTITEM);
       }
 
    sprintf(CURRENTITEM,"%s.%d.gz",name,i);
@@ -75,7 +75,7 @@ for (i = number-1; i > 0; i--)
    
    if (rename(CURRENTITEM,VBUFF) == -1)
       {
-      Debug("cfengine: rename failed in RotateFiles %s -> %s\n",name,CURRENTITEM);
+      Debug("Rename failed in RotateFiles %s -> %s\n",name,CURRENTITEM);
       }
 
    sprintf(CURRENTITEM,"%s.%d.Z",name,i);
@@ -83,7 +83,7 @@ for (i = number-1; i > 0; i--)
    
    if (rename(CURRENTITEM,VBUFF) == -1)
       {
-      Debug("cfengine: rename failed in RotateFiles %s -> %s\n",name,CURRENTITEM);
+      Debug("Rename failed in RotateFiles %s -> %s\n",name,CURRENTITEM);
       }   
    }
 
@@ -102,7 +102,8 @@ chmod(VBUFF,statbuf.st_mode);
 
 if ((fd = creat(name,statbuf.st_mode)) == -1)
    {
-   printf("%s: failed to create new %s in disable(rotate)\n",VPREFIX,name);
+   sprintf(OUTPUT,"Failed to create new %s in disable(rotate)\n",name);
+   CfLog(cferror,OUTPUT,"creat");
    }
 else
    {
