@@ -77,6 +77,8 @@ char *VVNAMES[] =
    "interfacename",
    "expireafter",
    "ifelapsed",
+   "fileextensions",
+   "suspiciousnames",
    NULL
    };
 
